@@ -1,4 +1,5 @@
 import abc   # 利用abc模块实现抽象类
+import inspect
 import json
 from urllib.parse import unquote
 
@@ -258,12 +259,23 @@ class HttpResponse(HttpBase):
     def response_data(self):
         """
         获取响应体
+        ------------------------------
+        0.4.0
+        增加对生成器的判定
+        他现在会将生成器直接返回
+        -----------------------------
         :return: bytes
         """
+        # 如果是二进制
         if isinstance(self.data, bytes):
             return [self.data]
+        # 如果是字符串
         elif isinstance(self.data, str):
             return [self.data.encode('utf-8')]
+        # 如果是一个可迭代对象
+        elif inspect.isgenerator(self.data):
+            return self.data
+        # 都不是则尝试解析这个对象
         else:
             _, data = parse_data(self.data)
             return [data.encode('utf-8')]
@@ -297,9 +309,16 @@ def parse_data(data):
     """
     通过递归来解析数据，将数据解析为json格式的字符串
     返回两个参数，bool为True说明字符串为json格式
+    --------------------------------------------
+    0.4.0
+    增加对生成器的判定
+    -------------------------------------------
+
     :param data: 待解析的数据
     :return: bool,str
     """
+    if inspect.isgenerator(data):
+        return False, data
 
     if isinstance(data, bytes):
         return False, data
